arithmetic

package
v2.7.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MutatorArithmeticAssignInvert

func MutatorArithmeticAssignInvert(_ *types.Package, _ *types.Info, node ast.Node) []mutator.Mutation

MutatorArithmeticAssignInvert implements a mutator to invert change assign statements.

func MutatorArithmeticAssignment

func MutatorArithmeticAssignment(_ *types.Package, _ *types.Info, node ast.Node) []mutator.Mutation

MutatorArithmeticAssignment implements a mutator to change base assign logic.

func MutatorArithmeticBase

func MutatorArithmeticBase(_ *types.Package, _ *types.Info, node ast.Node) []mutator.Mutation

MutatorArithmeticBase implements a mutator to change base arithmetic.

func MutatorArithmeticBitwise

func MutatorArithmeticBitwise(_ *types.Package, info *types.Info, node ast.Node) []mutator.Mutation

MutatorArithmeticBitwise implements a mutator to change bitwise arithmetic.

func MutatorArithmeticNegate added in v2.6.1

func MutatorArithmeticNegate(_ *types.Package, _ *types.Info, node ast.Node) []mutator.Mutation

MutatorArithmeticNegate inverts unary negation: -x becomes +x (effectively x). Mirrors gremlins' INVERT_NEGATIVES operator.

Types

This section is empty.

Jump to